server

package
v0.0.0-...-a907a0b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 7, 2026 License: MIT Imports: 39 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Server

type Server struct {
	// contains filtered or unexported fields
}

Server hosts the websocket gateway and the GoAkt actor system.

func NewServer

func NewServer(config *config.Config, logger log.Logger) *Server

NewServer creates an instance of Server

func (*Server) Start

func (s *Server) Start(ctx context.Context) error

Start boots the actor system, cluster components, and websocket listener.

func (*Server) Stop

func (s *Server) Stop(ctx context.Context) error

Stop shuts down the actor system and marks the server as stopped.

Jump to